==> ve-tos-java-sdk-2.6.0-sources.jar: com/volcengine/tos/model/bucket/CreateBucketV2Input.java <==
package com.volcengine.tos.model.bucket;

import com.volcengine.tos.comm.common.ACLType;
import com.volcengine.tos.comm.common.AzRedundancyType;
import com.volcengine.tos.comm.common.StorageClassType;

public class CreateBucketV2Input {
    private String bucket;
    private ACLType acl;
    private String grantFullControl;
    private String grantRead;
    private String grantReadAcp;
    private String grantWrite;
    private String grantWriteAcp;
    private StorageClassType storageClass;
    private AzRedundancyType azRedundancy;

    public CreateBucketV2Input() {
    }

    public CreateBucketV2Input(String bucket) {
        this.bucket = bucket;
    }

    public String getBucket() {
        return bucket;
    }

    public ACLType getAcl() {
        return acl;
    }

    public String getGrantFullControl() {
        return grantFullControl;
    }

    public String getGrantRead() {
        return grantRead;
    }

    public String getGrantReadAcp() {
        return grantReadAcp;
    }

    public String getGrantWrite() {
        return grantWrite;
    }

    public String getGrantWriteAcp() {
        return grantWriteAcp;
    }

    public StorageClassType getStorageClass() {
        return storageClass;
    }

    public AzRedundancyType getAzRedundancy() {
        return azRedundancy;
    }

    public CreateBucketV2Input setBucket(String bucket) {
        this.bucket = bucket;
        return this;
    }

    public CreateBucketV2Input setAcl(ACLType acl) {
        this.acl = acl;
        return this;
    }

    public CreateBucketV2Input setGrantFullControl(String grantFullControl) {
        this.grantFullControl = grantFullControl;
        return this;
    }

    public CreateBucketV2Input setGrantRead(String grantRead) {
        this.grantRead = grantRead;
        return this;
    }

    public CreateBucketV2Input setGrantReadAcp(String grantReadAcp) {
        this.grantReadAcp = grantReadAcp;
        return this;
    }

    public CreateBucketV2Input setGrantWrite(String grantWrite) {
        this.grantWrite = grantWrite;
        return this;
    }

    public CreateBucketV2Input setGrantWriteAcp(String grantWriteAcp) {
        this.grantWriteAcp = grantWriteAcp;
        return this;
    }

    public CreateBucketV2Input setStorageClass(StorageClassType storageClass) {
        this.storageClass = storageClass;
        return this;
    }

    public CreateBucketV2Input setAzRedundancy(AzRedundancyType azRedundancy) {
        this.azRedundancy = azRedundancy;
        return this;
    }

    public static CreateBucketInputV2Builder builder() {
        return new CreateBucketInputV2Builder();
    }

    @Override
    public String toString() {
        return "CreateBucketV2Input{" +
                "bucket='" + bucket + '\'' +
                ", acl=" + acl +
                ", grantFullControl='" + grantFullControl + '\'' +
                ", grantRead='" + grantRead + '\'' +
                ", grantReadAcp='" + grantReadAcp + '\'' +
                ", grantWrite='" + grantWrite + '\'' +
                ", grantWriteAcp='" + grantWriteAcp + '\'' +
                ", storageClass=" + storageClass +
                ", azRedundancy=" + azRedundancy +
                '}';
    }

    public static final class CreateBucketInputV2Builder {
        private String bucket;
        private ACLType acl;
        private String grantFullControl;
        private String grantRead;
        private String grantReadAcp;
        private String grantWrite;
        private String grantWriteAcp;
        private StorageClassType storageClass;
        private AzRedundancyType azRedundancy;

        private CreateBucketInputV2Builder() {
        }

        public CreateBucketInputV2Builder bucket(String bucket) {
            this.bucket = bucket;
            return this;
        }

        public CreateBucketInputV2Builder acl(ACLType acl) {
            this.acl = acl;
            return this;
        }

        public CreateBucketInputV2Builder grantFullControl(String grantFullControl) {
            this.grantFullControl = grantFullControl;
            return this;
        }

        public CreateBucketInputV2Builder grantRead(String grantRead) {
            this.grantRead = grantRead;
            return this;
        }

        public CreateBucketInputV2Builder grantReadAcp(String grantReadAcp) {
            this.grantReadAcp = grantReadAcp;
            return this;
        }

        public CreateBucketInputV2Builder grantWrite(String grantWrite) {
            this.grantWrite = grantWrite;
            return this;
        }

        public CreateBucketInputV2Builder grantWriteAcp(String grantWriteAcp) {
            this.grantWriteAcp = grantWriteAcp;
            return this;
        }

        public CreateBucketInputV2Builder storageClass(StorageClassType storageClass) {
            this.storageClass = storageClass;
            return this;
        }

        public CreateBucketInputV2Builder azRedundancy(AzRedundancyType azRedundancy) {
            this.azRedundancy = azRedundancy;
            return this;
        }

        public CreateBucketV2Input build() {
            CreateBucketV2Input createBucketInputV2 = new CreateBucketV2Input();
            createBucketInputV2.bucket = this.bucket;
            createBucketInputV2.acl = this.acl;
            createBucketInputV2.grantWriteAcp = this.grantWriteAcp;
            createBucketInputV2.grantReadAcp = this.grantReadAcp;
            createBucketInputV2.grantRead = this.grantRead;
            createBucketInputV2.grantFullControl = this.grantFullControl;
            createBucketInputV2.grantWrite = this.grantWrite;
            createBucketInputV2.storageClass = this.storageClass;
            createBucketInputV2.azRedundancy = this.azRedundancy;
            return createBucketInputV2;
        }
    }
}

==> ve-tos-java-sdk-2.7.0-sources.jar: com/volcengine/tos/model/bucket/CreateBucketV2Input.java <==
package com.volcengine.tos.model.bucket;

import com.volcengine.tos.comm.common.ACLType;
import com.volcengine.tos.comm.common.AzRedundancyType;
import com.volcengine.tos.comm.common.StorageClassType;

public class CreateBucketV2Input {
    private String bucket;
    private ACLType acl;
    private String grantFullControl;
    private String grantRead;
    private String grantReadAcp;
    private String grantWrite;
    private String grantWriteAcp;
    private StorageClassType storageClass;
    private AzRedundancyType azRedundancy;
    private String projectName;

    public CreateBucketV2Input() {
    }

    public CreateBucketV2Input(String bucket) {
        this.bucket = bucket;
    }

    public String getBucket() {
        return bucket;
    }

    public ACLType getAcl() {
        return acl;
    }

    public String getGrantFullControl() {
        return grantFullControl;
    }

    public String getGrantRead() {
        return grantRead;
    }

    public String getGrantReadAcp() {
        return grantReadAcp;
    }

    public String getGrantWrite() {
        return grantWrite;
    }

    public String getGrantWriteAcp() {
        return grantWriteAcp;
    }

    public StorageClassType getStorageClass() {
        return storageClass;
    }

    public AzRedundancyType getAzRedundancy() {
        return azRedundancy;
    }

    public CreateBucketV2Input setBucket(String bucket) {
        this.bucket = bucket;
        return this;
    }

    public CreateBucketV2Input setAcl(ACLType acl) {
        this.acl = acl;
        return this;
    }

    public CreateBucketV2Input setGrantFullControl(String grantFullControl) {
        this.grantFullControl = grantFullControl;
        return this;
    }

    public CreateBucketV2Input setGrantRead(String grantRead) {
        this.grantRead = grantRead;
        return this;
    }

    public CreateBucketV2Input setGrantReadAcp(String grantReadAcp) {
        this.grantReadAcp = grantReadAcp;
        return this;
    }

    public CreateBucketV2Input setGrantWrite(String grantWrite) {
        this.grantWrite = grantWrite;
        return this;
    }

    public CreateBucketV2Input setGrantWriteAcp(String grantWriteAcp) {
        this.grantWriteAcp = grantWriteAcp;
        return this;
    }

    public CreateBucketV2Input setStorageClass(StorageClassType storageClass) {
        this.storageClass = storageClass;
        return this;
    }

    public CreateBucketV2Input setAzRedundancy(AzRedundancyType azRedundancy) {
        this.azRedundancy = azRedundancy;
        return this;
    }

    public String getProjectName() {
        return projectName;
    }

    public CreateBucketV2Input setProjectName(String projectName) {
        this.projectName = projectName;
        return this;
    }

    public static CreateBucketInputV2Builder builder() {
        return new CreateBucketInputV2Builder();
    }

    @Override
    public String toString() {
        return "CreateBucketV2Input{" +
                "bucket='" + bucket + '\'' +
                ", acl=" + acl +
                ", grantFullControl='" + grantFullControl + '\'' +
                ", grantRead='" + grantRead + '\'' +
                ", grantReadAcp='" + grantReadAcp + '\'' +
                ", grantWrite='" + grantWrite + '\'' +
                ", grantWriteAcp='" + grantWriteAcp + '\'' +
                ", storageClass=" + storageClass +
                ", azRedundancy=" + azRedundancy +
                ", projectName='" + projectName + '\'' +
                '}';
    }

    public static final class CreateBucketInputV2Builder {
        private String bucket;
        private ACLType acl;
        private String grantFullControl;
        private String grantRead;
        private String grantReadAcp;
        private String grantWrite;
        private String grantWriteAcp;
        private StorageClassType storageClass;
        private AzRedundancyType azRedundancy;
        private String projectName;

        private CreateBucketInputV2Builder() {
        }

        public CreateBucketInputV2Builder bucket(String bucket) {
            this.bucket = bucket;
            return this;
        }

        public CreateBucketInputV2Builder acl(ACLType acl) {
            this.acl = acl;
            return this;
        }

        public CreateBucketInputV2Builder grantFullControl(String grantFullControl) {
            this.grantFullControl = grantFullControl;
            return this;
        }

        public CreateBucketInputV2Builder grantRead(String grantRead) {
            this.grantRead = grantRead;
            return this;
        }

        public CreateBucketInputV2Builder grantReadAcp(String grantReadAcp) {
            this.grantReadAcp = grantReadAcp;
            return this;
        }

        public CreateBucketInputV2Builder grantWrite(String grantWrite) {
            this.grantWrite = grantWrite;
            return this;
        }

        public CreateBucketInputV2Builder grantWriteAcp(String grantWriteAcp) {
            this.grantWriteAcp = grantWriteAcp;
            return this;
        }

        public CreateBucketInputV2Builder storageClass(StorageClassType storageClass) {
            this.storageClass = storageClass;
            return this;
        }

        public CreateBucketInputV2Builder azRedundancy(AzRedundancyType azRedundancy) {
            this.azRedundancy = azRedundancy;
            return this;
        }

        public CreateBucketInputV2Builder projectName(String projectName) {
            this.projectName = projectName;
            return this;
        }
        public CreateBucketV2Input build() {
            CreateBucketV2Input createBucketInputV2 = new CreateBucketV2Input();
            createBucketInputV2.bucket = this.bucket;
            createBucketInputV2.acl = this.acl;
            createBucketInputV2.grantWriteAcp = this.grantWriteAcp;
            createBucketInputV2.grantReadAcp = this.grantReadAcp;
            createBucketInputV2.grantRead = this.grantRead;
            createBucketInputV2.grantFullControl = this.grantFullControl;
            createBucketInputV2.grantWrite = this.grantWrite;
            createBucketInputV2.storageClass = this.storageClass;
            createBucketInputV2.azRedundancy = this.azRedundancy;
            createBucketInputV2.projectName = this.projectName;
            return createBucketInputV2;
        }
    }
}
